@@ -32,6 +32,11 @@ class ftpUtil:
             else:
                 duration=0
             fsize=os.path.getsize(local_path)
+            # 根据文件大小fsize和时间duration，在数据库中判断是否已采集(>0)，是的话就返回，否则继续
+            iexist=self.__mutil.sftp_file_repeat(fdesc,fsize,duration)
+            if iexist>0:
+                print("已采集过：%s" % fdesc)
+                return
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
@@ -58,7 +63,13 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head +pid +'/'+ remote_file, stud,fdesc,fsize,duration,ftype,pid)
+            self.__mutil.sftp_file_ins(local_path,
+                                       self.__url_head +pid +'/'+ remote_file,
+                                       stud,
+                                       fdesc,
+                                       fsize,
+                                       duration,
+                                       ftype,pid)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
